/*
 * @quakeStartAppPanel.java Version 1.1 08/03/2015
 *
 * Copyright (c) 2015 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package quake.gui;

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.border.*;

import cmn.cmnStruct;              // Common Data Structure
//import quake.gui.quakeFrame;
import quake.quakeDataListStruct;  // Quake Data List Structure
import quake.quakeSeisStruct;      // Quake Seismic Data Structure
import quake.io.ReadQuakeXMLFile;  // Read Quake XML Stream from KGS DB
//import quake.gui.quake2DPlotControlFrame;
import quake.gui.quakePlotTimeMagDataFrame;

/** Class quakeStartAppPanel
 *  <p> This Class Starting Panel for this web application
 *
 *  @version 1.1 08/03/2015
 *  @author  John R. Victorine
 */

public class quakeStartAppPanel extends JPanel implements ActionListener
{
  // Input Variables

  private JFrame     parent   = null; // Frame calling this panel
  private cmnStruct  stStruct = null; // Global Common Data Structure

  // Global Variable

  quakeDataListStruct     stList = null; // Quake Data List Structure
  //quake2DPlotControlFrame frame  = null; // Quake 2D Plot Control Frame

  quakePlotTimeMagDataFrame frame = null;

  // Global Panel Widgets

  private JButton    btn      = null;
  private JButton    btnExit  = new JButton();

  /** Constructor quakeStartAppPanel( JFrame parent, cmnStruct stStruct )
   *  <p> This is the Constructor for this class.
   *  @param parent   = the frame calling this panel
   *  @param stStruct = Global Common Data Structure
   */

  public quakeStartAppPanel( JFrame parent, cmnStruct stStruct )
  {
    try
    {
      this.parent   = parent;
      this.stStruct = stStruct;

      jbInit();
    }
    catch(Exception ex)
    {
      ex.printStackTrace();
    }
  }

  /** METHOD jbInit()
   *  <p> This Method will create the Panel for this class.
   *  @throws Exception
   */

  private void jbInit() throws Exception
  {
    JPanel pnlCenter = new JPanel();
    JPanel pnlBase   = new JPanel();

    JLabel lbl       = new JLabel();

    // Build Panel

    this.setLayout( new BorderLayout() );
    this.setBackground(Color.white);

    pnlCenter.setLayout( new BorderLayout() );
    pnlCenter.setBackground(Color.white);

    btn = new JButton( createImageIcon( cmn.cmnStruct.SEISMIC_APP) );
    btn.setBackground(Color.white);
    btn.addActionListener( this );

    lbl.setHorizontalAlignment(SwingConstants.CENTER);
    lbl.setFont(new java.awt.Font("Dialog", 1, 20));
    lbl.setBackground(Color.white);
    lbl.setText("Enter");

    pnlBase.setLayout( new GridLayout() );
    pnlBase.setBackground(Color.white);

    btnExit.setFont(new java.awt.Font("Dialog", 1, 11));
    btnExit.setText("Exit");
    btnExit.addActionListener(this);

    // Add Widgets to Panel

    this.add( pnlCenter,    BorderLayout.CENTER );
    pnlCenter.add( btn,     BorderLayout.CENTER );
    pnlCenter.add( lbl,     BorderLayout.SOUTH );

    if (parent != null)
    {
      this.add( pnlBase,    BorderLayout.SOUTH );
      pnlBase.add( btnExit, null );
    }
  }

  /** METHOD createImageIcon()
   *  <p> This Method will create the Frame for this class.
   *  @param path = the path to the image
   *  @return image icon
   */

  protected ImageIcon createImageIcon(String path)
  {
    java.net.URL imgURL = getClass().getResource(path);
    ImageIcon    image  = null;

    if (imgURL != null)
    {
      image = new ImageIcon(imgURL);
    }
    else
    {
       System.err.println("Couldn't find file: " + path);
    }

    return (image);
  }

  /* ===================================================================== *
   * ------------------------ READ QUAKE DATA ---------------------------- *
   * ===================================================================== */

  /** Method readData()
   * <p> This method will read the Earthquake Data from the KGS DB xml stream
   */

  public void readData()
  {
  	ReadQuakeXMLFile pRead = new ReadQuakeXMLFile(quake.io.ReadQuakeXMLFile.URL);
    stList = pRead.Process( cmn.cmnStruct.EARTHQUAKES );
  }

  /* ===================================================================== *
   * ---------------------------- ACTIONS -------------------------------- *
   * ===================================================================== */

  /** Method close()
   * <p> This method will close all dialogs that are opened by this class.
   */

  public void close()
  {
    // Input Variables

    stStruct = null;  // Global IQSTRAT Data Structure

    if (stList != null)
      stList.delete();
    stList = null;

    if (frame != null)
      frame.close();
    frame    = null;

    // Global Panel Widgets

    btn      = null;
    btnExit  = null;

    if (parent != null)
    {
      parent.dispose();
      parent = null;

      System.exit(0);
    }
  }

  /** METHOD actionPerformed()
   *  <p> This Method will handle all the actions within the Frame.
   *  @param event - Action Event
   */

  public void actionPerformed(ActionEvent event)
  {
    if (event.getSource() == btn)
    {
	  readData();

      quakeSeisStruct st = quake.quakeDataUtility.quakeGetSeismic(
		                     quake.quakeDataUtility._CENTRAL, stList);
//      quake.quakeSeisUtility.print(st);

      if (frame != null)
        frame.close();
      frame    = null;

//      frame = new quake2DPlotControlFrame(stStruct,
      frame = new quakePlotTimeMagDataFrame(
		        quake.quakeSeisUtility.copy( st ) );
	}

    if (event.getSource() == btnExit)
    {
	  close();
	}
  }
}


/*
 *  @version 1.1 08/03/2015
 *  @author  John Victorine
 */
