/*
 * @quakeSeisUtility.java Version 1.1 08/06/2015
 *
 * Copyright (c) 2015 Kansas Geological Survey
 * 1930 Constant Avenue, Lawrence, Kansas, 66047, U.S.A.
 * All Rights Reserved.
 */

package quake;

import java.sql.Timestamp;

import quake.quakeSeisStruct;  // Seismic Data Structure

/** Class quakeSeisUtility
 *  <p> This is the quake seismic data structure utility class.
 *
 *  @version 1.1 08/06/2015
 *  @author  John R. Victorine
 */

public class quakeSeisUtility
{
  /** Method quakeSeisStruct copy(quakeSeisStruct stOld)
   *  <p> This method will copy the seismic data structure
   *  @param  stOld = Old quake seismic data structure
   *  @return stNew = New quake seismic data structure
   */

  public static quakeSeisStruct copy(quakeSeisStruct stOld)
  {
	quakeSeisStruct stNew = null;

	if (stOld != null)
	{
	  stNew            = new quakeSeisStruct();

      stNew.network    = new String(stOld.network);  // Network Code
      stNew.station    = new String(stOld.station);  // Station Identifier
      stNew.location   = new String(stOld.location); // Location Identifier
      stNew.channel    = new String(stOld.channel);  // Channel Identifier

      stNew.tsStart    = new Timestamp(stOld.tsStart.getTime());
      stNew.tsEnd      = new Timestamp(stOld.tsEnd.getTime());

      stNew.dMaximum   = stOld.dMaximum;             // Maximum Data Value
      stNew.dMinimum   = stOld.dMinimum;             // Minimum Data Value

      // Seismic Records

      stNew.iRows      = stOld.iRows;                // Total Number of rows
      stNew.ts         = new Timestamp[stNew.iRows]; // Time Stamp of data record
      stNew.mag        = new double[stNew.iRows];    // Data record
      stNew.dLatitude  = new double[stNew.iRows];    // Latitude
      stNew.dLongitude = new double[stNew.iRows];    // Longitude
      stNew.depth      = new double[stNew.iRows];    // Depth

	  if (stNew.iRows > 0)
	  {
		for (int i=0; i<stNew.iRows; i++)
		{
		  stNew.ts[i]         = new Timestamp(stOld.ts[i].getTime());
		  stNew.mag[i]        = stOld.mag[i];        // Magnitude
          stNew.dLatitude[i]  = stOld.dLatitude[i];  // Latitude
          stNew.dLongitude[i] = stOld.dLongitude[i]; // Longitude
          stNew.depth[i]      = stOld.depth[i];      // Depth
		}
	  }
	}

	return (stNew);
  }

  /** Method print()
   *  <p> This method will print the Quake Seismic Data Structure
   */

  public static void print(quakeSeisStruct st)
  {
    if (st != null)
    {
      for (int i=0; i<st.iRows; i++)
      {
        System.out.println(st.ts[i].toString()+" "+st.mag[i]+" "+
                            st.dLatitude[i]+" "+st.dLongitude[i]+" "+st.depth[i]);
      }

      System.out.println("Min="+st.dMinimum+" Max="+st.dMaximum+" Start="+
                         st.tsStart.toString()+" End="+st.tsEnd.toString());
    }
  }
}

/*
 *  @version 1.1 08/06/2015
 *  @author  John Victorine
 */
